==> flutter_advanced_progress-0.0.1.tar.gz: lib/src/widget.dart <==
part of '../flutter_advanced_progress.dart';

class AdvancedProgress extends StatelessWidget {
  AdvancedProgress({
    Key key,
    @required this.levelAmount,
    @required this.radius,
    this.primaryValue,
    this.secondaryValue,
    this.secondaryWidth = 10.0,
    this.startAngle = 120.0,
    this.maxDegrees = 300.0,
    this.progressGap = 0.0,
    this.division = 10,
    this.levelWidth = 1.0,
    this.levelLow = 8.0,
    this.levelHigh = 16.0,
    this.primaryColor,
    this.secondaryColor,
    this.tertiaryColor,
    this.child,
  }) : super(key: key);

  final int levelAmount;
  final double primaryValue;
  final double secondaryValue;
  final double secondaryWidth;
  final double radius;
  final double startAngle;
  final double maxDegrees;
  final double progressGap;
  final int division;
  final double levelWidth;
  final double levelLow;
  final double levelHigh;
  final Color primaryColor;
  final Color secondaryColor;
  final Color tertiaryColor;
  final Widget child;

  @override
  Widget build(BuildContext context) {
    final theme = Theme.of(context);

    final size = radius * 2;

    return Container(
      clipBehavior: Clip.antiAlias,
      width: size,
      height: size,
      decoration: BoxDecoration(),
      child: CustomPaint(
        painter: AdvancedProgressPainter(
          amount: levelAmount,
          primaryValue: primaryValue,
          secondaryValue: secondaryValue,
          secondaryWidth: secondaryWidth,
          radius: radius,
          startAngle: startAngle,
          maxDegrees: maxDegrees,
          progressGap: progressGap,
          division: division,
          levelWidth: levelWidth,
          levelLow: levelLow,
          levelHigh: levelHigh,
          primaryColor: primaryColor ?? theme.indicatorColor,
          secondaryColor: secondaryColor ?? primaryColor,
          tertiaryColor: tertiaryColor ?? theme.hintColor,
        ),
        child: child,
      ),
    );
  }
}

==> flutter_advanced_progress-0.0.2.tar.gz: lib/src/widget.dart <==
part of '../flutter_advanced_progress.dart';

/// Advanced progress widget.
/// Represents two progress, primary and secondary.
class AdvancedProgress extends StatelessWidget {
  AdvancedProgress({
    Key key,
    this.primaryValue,
    this.secondaryValue,
    this.secondaryWidth = 10.0,
    @required this.radius,
    this.startAngle = 120.0,
    this.maxDegrees = 300.0,
    this.progressGap = 0.0,
    this.division = 10,
    @required this.levelAmount,
    this.levelWidth = 1.0,
    this.levelLow = 8.0,
    this.levelHigh = 16.0,
    this.primaryColor,
    this.secondaryColor,
    this.tertiaryColor,
    this.child,
  }) : super(key: key);

  /// Value for primary progress.
  final double primaryValue;

  /// Value for secondary progress.
  final double secondaryValue;

  /// Secondary progress width.
  final double secondaryWidth;

  /// Total radius for whole widget.
  final double radius;

  /// Progress start angle.
  final double startAngle;

  /// Progress degrees from [startAngle].
  final double maxDegrees;

  /// Gap between primary and secondary progress.
  final double progressGap;

  /// Primary progress division.
  final int division;

  /// Amount of levels on primary progress.
  final int levelAmount;

  /// Width of levels on primary progress.
  final double levelWidth;

  /// Height of low levels on primary progress.
  final double levelLow;

  /// Height of high levels managed by [division] on primary progress.
  final double levelHigh;

  /// Primary color that used as a color for progress of first in gradient.
  /// User for primary and secondary progress.
  final Color primaryColor;

  /// Secondary color that used last in gradient.
  /// User for primary and secondary progress.
  final Color secondaryColor;

  /// Tertiary color that used for inactive part of progress.
  /// User for primary and secondary progress.
  final Color tertiaryColor;

  /// Child widget.
  final Widget child;

  @override
  Widget build(BuildContext context) {
    final theme = Theme.of(context);

    final size = radius * 2;

    return Container(
      clipBehavior: Clip.antiAlias,
      width: size,
      height: size,
      decoration: BoxDecoration(),
      child: CustomPaint(
        painter: AdvancedProgressPainter(
          primaryValue: primaryValue,
          secondaryValue: secondaryValue,
          secondaryWidth: secondaryWidth,
          radius: radius,
          startAngle: startAngle,
          maxDegrees: maxDegrees,
          progressGap: progressGap,
          division: division,
          levelAmount: levelAmount,
          levelWidth: levelWidth,
          levelLow: levelLow,
          levelHigh: levelHigh,
          primaryColor: primaryColor ?? theme.indicatorColor,
          secondaryColor: secondaryColor ?? primaryColor,
          tertiaryColor: tertiaryColor ?? theme.hintColor,
        ),
        child: child,
      ),
    );
  }
}
